==> open-xchange-documents-backend_7.10.2.orig.tar.bz2: open-xchange-documents-backend-7.10.2/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/CTMergeCell.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *   
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.xlsx4j.sml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;

/**
 * <p>Java class for CT_MergeCell complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_MergeCell">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="ref" use="required" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}ST_Ref" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_MergeCell")
public class CTMergeCell implements ICellRefRangeAccess
{
    @XmlTransient
    private SmlUtils.CellRefRange cellRefRange;

    /**
     * Gets the value of the ref property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @XmlAttribute(name = "ref", required = true)
    protected String getRef() {
    	if(cellRefRange==null) {
    		return "";
    	}
        return SmlUtils.getCellRefRange(cellRefRange);
    }

    /**
     * Sets the value of the ref property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    protected void setRef(String value) {
    	cellRefRange = SmlUtils.createCellRefRange(value);
    }

    public SmlUtils.CellRefRange getCellRefRange(boolean forceCreate) {
    	if(cellRefRange==null&&forceCreate) {
    		cellRefRange = new SmlUtils.CellRefRange();
    	}
    	return cellRefRange;
    }

    public void setCellRefRange(SmlUtils.CellRefRange range) {
    	cellRefRange = range;
    }
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.docx4j/src/xlsx4j/java/org/xlsx4j/sml/CTMergeCell.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *   
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.xlsx4j.sml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import com.openexchange.office.filter.core.spreadsheet.ICellRefRangeAccess;
import com.openexchange.office.filter.core.spreadsheet.SmlUtils;

/**
 * <p>Java class for CT_MergeCell complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_MergeCell">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="ref" use="required" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}ST_Ref" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_MergeCell")
public class CTMergeCell implements ICellRefRangeAccess
{
    @XmlTransient
    private SmlUtils.CellRefRange cellRefRange;

    /**
     * Gets the value of the ref property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    @XmlAttribute(name = "ref", required = true)
    protected String getRef() {
    	if(cellRefRange==null) {
    		return "";
    	}
        return SmlUtils.getCellRefRange(cellRefRange);
    }

    /**
     * Sets the value of the ref property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    protected void setRef(String value) {
    	cellRefRange = SmlUtils.createCellRefRange(value);
    }

    public SmlUtils.CellRefRange getCellRefRange(boolean forceCreate) {
    	if(cellRefRange==null&&forceCreate) {
    		cellRefRange = new SmlUtils.CellRefRange();
    	}
    	return cellRefRange;
    }

    public void setCellRefRange(SmlUtils.CellRefRange range) {
    	cellRefRange = range;
    }
}
